package com.goldencode.p2j.testengine;

import org.junit.platform.engine.*;
import org.junit.platform.engine.support.descriptor.*;
import org.junit.platform.engine.support.hierarchical.*;
import org.junit.platform.engine.support.hierarchical.Node.*;

/**
 * Engine descriptor. Provides this engine unique ID and same thread execution mode. 
 */
public class FWDEngineDescriptor
extends EngineDescriptor
implements Node<FWDEngineExecutionContext>
{

   /**
    * The constructor.
    * 
    * @param uniqueId the {@code UniqueId} for the described {@code TestEngine};
    * never {@code null}
    */
   public FWDEngineDescriptor(UniqueId uniqueId)
   {
      super(uniqueId, "FWD Test");
   }

   /**
    * Get the preferred of {@linkplain ExecutionMode execution mode} for
    * parallel execution of this node.
    *
    * <p>The default implementation returns {@link ExecutionMode#CONCURRENT}.
    *
    * @return the preferred execution mode of this node; never {@code null}
    * @since 1.3
    * @see ExecutionMode
    */
   @Override
   public ExecutionMode getExecutionMode() {
      // No concurrent execution is planned yet
      return ExecutionMode.SAME_THREAD;
   }

}
